ZMetric
=======

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: ZMetric
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ZMetric.base_cls
      ~ZMetric.binarize
      ~ZMetric.closed_expectation
      ~ZMetric.closed_variance
      ~ZMetric.increasing
      ~ZMetric.key
      ~ZMetric.needs_candidates
      ~ZMetric.supported_rank_types
      ~ZMetric.supports_weights
      ~ZMetric.synonyms
      ~ZMetric.value_range

   .. rubric:: Methods Summary

   .. autosummary::

      ~ZMetric.__call__
      ~ZMetric.adjust
      ~ZMetric.expected_value
      ~ZMetric.extra_repr
      ~ZMetric.get_coefficients
      ~ZMetric.get_description
      ~ZMetric.get_link
      ~ZMetric.get_range
      ~ZMetric.get_sampled_values
      ~ZMetric.iter_extra_repr
      ~ZMetric.numeric_expected_value
      ~ZMetric.numeric_expected_value_with_ci
      ~ZMetric.numeric_variance
      ~ZMetric.numeric_variance_with_ci
      ~ZMetric.std
      ~ZMetric.variance

   .. rubric:: Attributes Documentation

   .. autoattribute:: base_cls
   .. autoattribute:: binarize
   .. autoattribute:: closed_expectation
   .. autoattribute:: closed_variance
   .. autoattribute:: increasing
   .. autoattribute:: key
   .. autoattribute:: needs_candidates
   .. autoattribute:: supported_rank_types
   .. autoattribute:: supports_weights
   .. autoattribute:: synonyms
   .. autoattribute:: value_range

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: adjust
   .. automethod:: expected_value
   .. automethod:: extra_repr
   .. automethod:: get_coefficients
   .. automethod:: get_description
   .. automethod:: get_link
   .. automethod:: get_range
   .. automethod:: get_sampled_values
   .. automethod:: iter_extra_repr
   .. automethod:: numeric_expected_value
   .. automethod:: numeric_expected_value_with_ci
   .. automethod:: numeric_variance
   .. automethod:: numeric_variance_with_ci
   .. automethod:: std
   .. automethod:: variance
